%--------------------------------------------------------------------------
% Figure 8 - Global fit of signals from different experiments
%--------------------------------------------------------------------------
% This DeerLab script was used to make Fig.8 of the paper: 
%
% Luis Fabregas Ibanez, Gunnar Jeschke, Stefan Stoll 
% DeerLab: A comprehensive toolbox for analyzing dipolar EPR spectroscopy data
% Magnetic Resonance, 2020
%
% DeerLab version: 
%   Release: 0.9.0
%--------------------------------------------------------------------------

clc,clear,clf

% Generate ground truth distance distribution
[r,P] = groundtruth('figure8');

% Define background model
kappa = 0.25;
Bmodel = @(t,lam)bg_exp(t,kappa,lam);

% Simulate a 4pDEER signal  (main pathway at start of signal, secondary pathway at the end)
rng(1)
t4p = linspace(-0.3,3.2,300);
pathways(1,:) = [0.8 NaN];
pathways(2,:) = [0.2 0];
V4p = dipolarkernel(t4p,r,pathways,Bmodel)*P + whitegaussnoise(t4p,0.01);

% Simulate a 5pDEER signal (main pathway at start of signal, secondary pathway at the middle)
rng(2)
t5p = linspace(-0.3,6.5,300);
pathways(1,:) = [0.4 NaN];
pathways(2,:) = [0.4 0];
pathways(3,:) = [0.2 max(t5p)/2];
V5p = dipolarkernel(t5p,r,pathways,Bmodel)*P  + whitegaussnoise(t5p,0.01);

% Collect signals for global-fit
Vs = {V4p,V5p};
ts = {t4p,t5p};

% Run global fit
[Vfit,Pfit] = fitsignal({V4p,V5p},{t4p,t5p},r,'P',@bg_exp,{@ex_4pdeer,@ex_5pdeer});
V4pfit = Vfit{1};
V5pfit = Vfit{2};

% Plot results
clf
subplot(121),hold on
plot(t4p,V4p,'k.',t4p,V4pfit)
plot(t5p,V5p + 0.5,'k.',t5p,V5pfit + 0.5)
axis tight, grid on, box on
xlabel('t [\mus]'),ylabel('V(t)')
legend('4pDEER data','4pDEER fit','5pDEER data','5pDEER fit','Location','best')

subplot(122)
plot(r,P,'k',r,Pfit,'b')
axis tight, grid on, box on
xlabel('r [nm]'),ylabel('P(r) [nm^{-1}]')
legend('truth','global fit')


